#!/usr/bin/env node

var fs = require('fs')
var path = require('path')
var program = require('commander')
var chalk = require('chalk')
var axios = require('axios')
var readlineSync = require('readline-sync')
var logger = require('../utils/logger')
var rewriteProfile = require('../utils/rewrite-profile')
var getProfile = require('../utils/get-profile')

var teamId = getProfile('ticket_teamId')
var MEMBER_LIST_URL = 'http://api.ticket.fed.guahao-inc.com/team/apply?teamId=' + teamId
var APPLY_URL = 'http://api.ticket.fed.guahao-inc.com/team/apply'

program
  .version(require('../package.json').version)
  .option('-u, --user [name]', '设置个人姓名')
  .option('-a, --apply', '加班报名')
  .option('-l, --list', '查看已报名列表')
  .option('-s, --search [name]', '查看是否已经报名')
  .option('-t, --teamId [id]', '设置teamId')
  .option('-c, --cancel', '取消报名')
  .parse(process.argv)

if (program.user) {
  rewriteProfile('user', program.user)
  logger.success('设置个人姓名成功')
}

if (program.teamId) {
  rewriteProfile('ticket_teamId', program.teamId)
  logger.success('设置teamId成功')
}

if (program.apply) {
  var user = getProfile('user')
  if (!user) {
    return logger.error('请先使用命令 wy ticket -u [name] 设置你的姓名')
  }

  axios.post(APPLY_URL, {
    teamId: teamId,
    userName: user
  }).then(res => {
    var data = res.data
    if (data.err === 0 && data.data.indexOf(user) !== -1) {
      logger.success('报名成功')
    } else {
      logger.error('报名失败' + data.msg && ':' + data.msg)  
    }
  })
}

if (program.list) {
  axios.get(MEMBER_LIST_URL).then(res => {
    var member = res.data.data.member
    logger.custom('green', '已报名 ' + member.length + ' 人')
    logger.custom('green', '------------')
    member.forEach(function (item, index) {
      logger.custom('yellow', item.name)
    })
  })
}

if (program.search) {
  axios.get(MEMBER_LIST_URL).then(res => {
    var user = program.search || getProfile('user')
    if (!user) {
      return logger.error('请输入需要查询的姓名，例如: wy-ticket -s 周梦楠')
    }
    var member = res.data.data.member
    var isApply = member.filter(v => v.name === program.search).length
    if (isApply) {
      logger.success(user + ' 已报名')
    } else {
      logger.error(user + ' 未报名')
    }
  })
}

if (program.cancel) {
  if (readlineSync.keyInYN('每日只能报名一次，取消后不可再次报名，是否取消报名？')) {
    var user = getProfile('user')
    if (!user) {
      return logger.error('请先使用命令 wy ticket -u [name] 设置你的姓名')
    }
    axios.delete(APPLY_URL, {
      teamId: teamId,
      userName: user
    }).then(res => {
      var data = res.data
      if (data.err === 0 && data.data.indexOf(user) === -1) {
        logger.success('取消报名成功')
      } else {
        logger.error('取消报名失败' + data.msg && ':' + data.msg)  
      }
    })
  }
}